pub struct PythonProcess { /* private fields */ }Expand description
A persistent Python child process that executes filter commands.
Implementations
Sourceimpl PythonProcess
impl PythonProcess
Sourcepub fn spawn(
python_path: &str,
filters: &[(String, Vec<u8>, bool)],
) -> Result<Self>
pub fn spawn( python_path: &str, filters: &[(String, Vec<u8>, bool)], ) -> Result<Self>
Spawn a Python daemon and load filters into it.
pub fn fit( &mut self, node_id: &str, data: &Value, y: Option<&Value>, ) -> Result<Value>
pub fn forward( &mut self, node_id: &str, data: &Value, state: &Value, ) -> Result<Value>
pub fn composite_fit( &mut self, node_ids: &[String], data: &Value, y: Option<&Value>, ) -> Result<(Value, HashMap<String, Value>)>
pub fn composite_forward( &mut self, node_ids: &[String], data: &Value, ) -> Result<Value>
pub fn get_state(&mut self, node_id: &str) -> Result<Value>
pub fn set_state(&mut self, node_id: &str, state: &Value) -> Result<()>
pub fn get_gradients(&mut self, node_id: &str) -> Result<Value>
pub fn apply_gradients( &mut self, node_id: &str, gradients: &Value, ) -> Result<()>
pub fn shutdown(&mut self)
pub fn node_ids(&self) -> &[String]